@@ -1,11 +1,11 @@
-import { CommonModule } from "@angular/common";
-import { NgModule } from "@angular/core";
-import { Routes } from "@angular/router";
-import { FormsModule } from "@angular/forms";
-import { NzIconModule } from "ng-zorro-antd/icon";
-import { RouterModule } from "@angular/router";
-import { HttpClientModule } from "@angular/common/http";
-import { GisDiagramComponent } from "./gisDiagram.component";
+import { CommonModule } from "@angular/common"
+import { NgModule } from "@angular/core"
+import { Routes } from "@angular/router"
+import { FormsModule } from "@angular/forms"
+import { NzIconModule } from "ng-zorro-antd/icon"
+import { RouterModule } from "@angular/router"
+import { HttpClientModule } from "@angular/common/http"
+import { GisDiagramComponent } from "./gisDiagram.component"
 import {
     TupleActionPushNameService,
     TupleActionPushOfflineService,
@@ -15,34 +15,34 @@ import {
     TupleDataOfflineObserverService,
     TupleOfflineStorageNameService,
     TupleOfflineStorageService,
-} from "@synerty/vortexjs";
+} from "@synerty/vortexjs"
 import {
     gisDiagramFilt,
     gisDiagramObservableName,
     gisDiagramTupleOfflineServiceName,
-} from "@peek/peek_plugin_gis_diagram/_private/PluginNames";
-import { ShowDiagramComponent } from "./show-diagram/show-diagram.component";
-import { gisDiagramActionProcessorName } from "@peek/peek_plugin_gis_diagram/_private";
-import { PeekPluginDiagramModule } from "@peek/peek_plugin_diagram";
+} from "@peek/peek_plugin_gis_diagram/_private/PluginNames"
+import { ShowDiagramComponent } from "./show-diagram/show-diagram.component"
+import { gisDiagramActionProcessorName } from "@peek/peek_plugin_gis_diagram/_private"
+import { PeekPluginDiagramModule } from "@peek/peek_plugin_diagram"
 
 export function tupleActionPushNameServiceFactory() {
     return new TupleActionPushNameService(
         gisDiagramActionProcessorName,
         gisDiagramFilt
-    );
+    )
 }
 
 export function tupleDataObservableNameServiceFactory() {
     return new TupleDataObservableNameService(
         gisDiagramObservableName,
         gisDiagramFilt
-    );
+    )
 }
 
 export function tupleOfflineStorageNameServiceFactory() {
     return new TupleOfflineStorageNameService(
         gisDiagramTupleOfflineServiceName
-    );
+    )
 }
 
 // Define the child routes for this plugin.
@@ -52,7 +52,7 @@ export const pluginRoutes: Routes = [
         pathMatch: "full",
         component: GisDiagramComponent,
     },
-];
+]
 
 // Define the root module for this plugin.
 // This module is loaded by the lazy loader, what ever this defines is what is started.
@@ -88,4 +88,5 @@ export const pluginRoutes: Routes = [
     ],
     declarations: [GisDiagramComponent, ShowDiagramComponent],
 })
-export class GisDiagramModule {}
+export class GisDiagramModule {
+}
